@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://e-valkov.org/linterna-magica
+// @source http://linterna-magica.nongnu.org
 
 // END OF LICENSE HEADER
 
@@ -37,7 +37,7 @@ LinternaMagica.prototype.create_about_box = function(id)
 
     var p = document.createElement("p");
     var text = document.createTextNode(
-	this.name+_(" version: ")+this.version);
+	this.name+this._(" version: ")+this.version);
     p.appendChild(text);
     box.appendChild(p);
 
@@ -50,38 +50,93 @@ LinternaMagica.prototype.create_about_box = function(id)
 	box.appendChild(p);
     }
 
+    // Translators 
+    if (this.languages[this.lang] &&
+	this.languages[this.lang].__translators)
+    {
+	var transl = null;
+	if (typeof (this.languages[this.lang].__translators) == "object")
+	{
+	    transl = this.languages[this.lang].__translators;
+	}
+	else
+	{
+	    transl = new Array();
+	    transl.push(this.languages[this.lang].__translators);
+	}
+
+	p = document.createElement("p");
+	text = document.createTextNode(this._("Translation")+":");
+	p.appendChild(text);
+	box.appendChild(p);
+
+	for (var l=0, length=transl.length; l< length; l++)
+	{
+	    p = document.createElement("p");
+	    text = document.createTextNode(transl[l]);
+	    p.appendChild(text);
+	    box.appendChild(p);
+	}
+    }
+
     // Info
     p = document.createElement("p");
-    text = document.createTextNode(this.description);
+    text = document.createTextNode(this.description());
     p.appendChild(text);
     box.appendChild(p);
 
     // License
     p = document.createElement("p");
-    text = document.createTextNode(this.license);
+    text = document.createTextNode(this.license());
     p.appendChild(text);
     box.appendChild(p);
 
     var license_link = this.pack_external_link(this.license_link,
 					  this.license_link);
 
+    license_link.setAttribute("title", this.license_link);
     p = document.createElement('p');
     p.appendChild(license_link);
     box.appendChild(p);
 
-    var homepage = this.pack_external_link(this.homepage,
-					   _("Linterna Mágica Home page"));
+    var homepage = 
+	this.pack_external_link(this.homepage,
+				this._("Linterna Mágica Home page"));
 
+    homepage.setAttribute("title", this.homepage);
     p = document.createElement('p');
     p.appendChild(homepage);
     box.appendChild(p);
 
-    // We want this for small objects. Scroll bars will be visible and
-    // license and home page links accessible.
-    if (!/youtube\.com/i.test(window.location.hostname))
-    {
-	box.style.setProperty("overflow", "auto", "important");
-    }
+    var savannah_link = 
+	this.pack_external_link(
+	    this.savannah_page,
+	    this._("Linterna Mágica project page at Savannah"));
+
+    savannah_link.setAttribute("title", this.savannah_page);
+    p = document.createElement("p");
+    p.appendChild(savannah_link);
+    box.appendChild(p);
+
+    var bug_report_link = 
+	this.pack_external_link(
+	    this.bug_report_link,
+	    this._("Report a bug at our Savannah project page"));
+
+    bug_report_link.setAttribute("title", this.bug_report_link);
+    p = document.createElement("p");
+    p.appendChild(bug_report_link);
+    box.appendChild(p);
+
+    var microblog_link = 
+	this.pack_external_link(
+	    this.microblog_link,
+	    this._("Linterna Mágica microbloging group at Identi.ca"));
+
+    microblog_link.setAttribute("title", this.microblog_link);
+    p = document.createElement("p");
+    p.appendChild(microblog_link);
+    box.appendChild(p);
 
     return box;
 }
